<!--
 * @Author: shy
 * @Description: 
 * @LastEditTime: 2020-12-11 17:26:58
-->
# just_utils
A series of convenience functions to help training large image dataset with CNN

## install

1. from source

```python
git clone https://github.com/hansoluo/cvutils.git
cd cvutils
python install setup.py
```

2. from pypi

```python
pip install just_utils
```